@@ -70,16 +70,13 @@ int main(int argc, char *argv[])
 
     MainWindow w;
 
-
-
-
-
-    QSettings oSettings("janbergmann", "simplenotewidget");
-    QColor cldefault = oSettings.value("bgcolor", QColor(255,255,0)).value<QColor>();
-
-
-    int bgcoloralpha = oSettings.value("bgcoloralpha", int(200)).toInt();
+    QSettings *oSettings;
+    oSettings = new QSettings("janbergmann", "simplenotewidget");
+    QColor cldefault = oSettings->value("bgcolor", QColor(255,255,0)).value<QColor>();
+    int bgcoloralpha = oSettings->value("bgcoloralpha", int(200)).toInt();
     cldefault.setAlpha(bgcoloralpha);
+    delete oSettings;
+
 
     //QColor cldefault = QColor(255,255,0);
     //cldefault.setAlpha(200);
