@@ -2,17 +2,11 @@
 #include "ui_mainwindow.h"
 #include "dialog.h"
 #include "settingsdlg.h"
-
 #include <QDateTime>
 #include <QMessageBox>
 #include <qinputdialog.h>
 #include <QStyleOption>
-#include <QPainter>
-#include <QPaintEvent>
-#include <QByteArray>
 #include <QCoreApplication>
-#include <QPainter>
-#include <QPaintEvent>
 #include <QMovie>
 #include <QDialog>
 #include <QSettings>
@@ -86,16 +80,12 @@ MainWindow::MainWindow(QWidget *parent) :
         if (event->xclient.message_type == appletShowSettingAtom )
         {
           //QMessageBox::information(0, "Settings", "will implement this in a future release", QMessageBox::Ok);
+          settingsdlg w(0);
+          //w->setAttribute(Qt::WA_Maemo5StackedWindow);
+          w.setProperty("FingerScrollable", true);
+          w.exec();
+          SetupThisUi();
 
-            settingsdlg w(0);
-            w.setProperty("FingerScrollable", true);
-            w.exec();
-
-
-
-            SetupThisUi();
-            //this->centralWidget()->update();
-            //this->centralWidget()->repaint();
 
           return true;
         }
@@ -106,15 +96,32 @@ MainWindow::MainWindow(QWidget *parent) :
 void MainWindow::SetupThisUi()
 {
 
-
-    QSettings oSettings("janbergmann", "simplenotewidget");
-    QColor cldefault = oSettings.value("bgcolor", QColor(255,255,0)).value<QColor>();
-    QColor cllabelcolor = oSettings.value("lblcolor", QColor(0,0,0)).value<QColor>();
-    QColor cltextedit = oSettings.value("txtcolor", QColor(0,0,0)).value<QColor>();
-    int bgcoloralpha = oSettings.value("bgcoloralpha", int(180)).toInt();
+    QSettings *oSettings;
+    oSettings = new QSettings("janbergmann", "simplenotewidget");
+    QColor cldefault = oSettings->value("bgcolor", QColor(255,255,0)).value<QColor>();
+    QColor cllabelcolor = oSettings->value("lblcolor", QColor(0,0,0)).value<QColor>();
+    QColor cltextedit = oSettings->value("txtcolor", QColor(0,0,0)).value<QColor>();
+    int bgcoloralpha = oSettings->value("bgcoloralpha", int(180)).toInt();
     cldefault.setAlpha(bgcoloralpha);
+    int fontSizeIndex = oSettings->value("fontsize", int(1)).toInt();
+    QString fontFamilyName = oSettings->value("fontfamily", "Nokia Sans SemiBold").toString();
 
-
+    switch(fontSizeIndex)
+    {
+     case 0: fontSizeIndex = 6;
+             break;
+     case 1: fontSizeIndex = 8;
+             break;
+     case 2: fontSizeIndex = 10;
+             break;
+     case 3: fontSizeIndex = 12;
+             break;
+     case 4: fontSizeIndex = 16;
+             break;
+     case 5: fontSizeIndex = 24;
+             break;
+     case 6: fontSizeIndex = 32;
+    }
 
     QPalette pal = this->palette();
     this->setAttribute(Qt::WA_TranslucentBackground);
@@ -122,7 +129,7 @@ void MainWindow::SetupThisUi()
 
     pal.setColor(QPalette::Window, cldefault);
     this->setPalette(pal);
-    this->ensurePolished(); // workaround Oxygen filling the background
+    this->ensurePolished();
     this->setAttribute(Qt::WA_StyledBackground, false);
 
 
@@ -144,8 +151,8 @@ void MainWindow::SetupThisUi()
     ui->teMain->setFrameShadow(QFrame::Plain);
     ui->teMain->setFrameShape(QFrame::NoFrame);
     ui->teMain->setPalette(QPalette(cltextedit,cldefault,cldefault,cltextedit,cltextedit,cltextedit,cldefault,cldefault,cldefault));
-    ui->teMain->setFontFamily("Nokia Sans SemiBold");
-    ui->teMain->setFontPointSize(8);
+    ui->teMain->setFontFamily(fontFamilyName);
+    ui->teMain->setFontPointSize(fontSizeIndex);
     ui->teMain->setWordWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere);
     ui->teMain->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     ui->teMain->setReadOnly(true);
@@ -156,7 +163,7 @@ void MainWindow::SetupThisUi()
 
     ui->lblDate->setLayoutDirection(Qt::RightToLeft);
     ui->lblDate->setPalette(QPalette(cllabelcolor,cllabelcolor,cllabelcolor,cllabelcolor,cllabelcolor,cllabelcolor,cldefault,cldefault,cldefault));
-    ui->lblDate->setFont(QFont("Nokia Sans SemiBold",10,10));
+    ui->lblDate->setFont(QFont(fontFamilyName,10,10));
 
 
     QPalette p = palette();
@@ -173,12 +180,17 @@ void MainWindow::SetupThisUi()
        ui->teMain->setProperty("FingerScrollable", true);
 #endif
 
-   ui->teMain->setText(oSettings.value("note","").toString());
-   ui->lblDate->setText(oSettings.value("notedate",QDateTime::currentDateTime().toString("dd.MM.yyyy   HH:mm")).toString());
+   ui->teMain->setText(oSettings->value("note","").toString());
+   ui->lblDate->setText(oSettings->value("notedate",QDateTime::currentDateTime().toString("dd.MM.yyyy   HH:mm")).toString());
+
+   delete oSettings;
+
 
    ui->centralWidget->repaint();
    this->repaint();
 
+   //ui->lblDate->setText(fontFamilyName);
+
 }
 
 
@@ -206,9 +218,12 @@ void MainWindow::changeEvent(QEvent *e)
 void MainWindow::on_pbEdit_clicked()
 {
     SetupThisUi();
+    //settingsdlg w(0);
     Dialog w(0);
     w.exec();
-    QSettings oSettings("janbergmann", "simplenotewidget");
-    ui->teMain->setText(oSettings.value("note","").toString());
-    ui->lblDate->setText(oSettings.value("notedate",QDateTime::currentDateTime().toString("dd.MM.yyyy   HH:mm")).toString());
+    QSettings *oSettings;
+    oSettings = new QSettings("janbergmann", "simplenotewidget");
+    ui->teMain->setText(oSettings->value("note","").toString());
+    ui->lblDate->setText(oSettings->value("notedate",QDateTime::currentDateTime().toString("dd.MM.yyyy   HH:mm")).toString());
+    delete oSettings;
 }
