@@ -17,10 +17,12 @@ public:
 
 protected:
     void changeEvent(QEvent *e);
-
+    #ifdef Q_WS_HILDON
+    bool x11Event ( XEvent * event );
+    #endif
 private:
     Ui::MainWindow *ui;
-    void LoadItems();
+    void SetupThisUi();
 
 
 private slots:
